@@ -1,14 +1,11 @@
 from arc.middleware import Middleware
-from arc.defaults import DefaultMiddleware, DefaultExceptionHandler
+from arc.defaults import LoggingMiddleware, DefaultExceptionHandler
 from arc.staticfiles import StaticFile
+from arc.logger import Logger
 from jinja2.loaders import FileSystemLoader
-from starlette.requests import Request
-from starlette.staticfiles import StaticFiles
 import uvicorn
 from parse import parse
 from jinja2 import Environment, FileSystemLoader
-from whitenoise import WhiteNoise
-import socket
 import inspect
 import os
 import traceback
@@ -21,7 +18,7 @@ class App:
 
     from arc import App
 
-    app = App("app")
+    app = App()
 
     @app.route("/")
     def index(req, res):
@@ -32,13 +29,6 @@ class App:
 
     The app has several parameters.
 
-    ..name ::
-        This paramter is used to specifiy the apps name. It is required, and has to be the same as the variable name
-        you assigned the App class to.
-
-        app = App("app")
-
-
     ..templates_dir ::
         This parameter is used to specify the directory that jinja loads its HTML templates from. Its defaulted to 
         the 'templates' directory, but you can change it as the following::
@@ -70,14 +60,20 @@ class App:
 
         app = App(port=8000)
 
-    ..default_middleware
-        This parameter specifies whether the app should use the default middleware, which logs requests and
-        responses into the console. Its set to True by default. You can change it as the following::
+    ..logging
+        This parameter specifies whether the apps default logger should be activated. It can
+        be deactivated as the following::
 
-        app = App(default_middleware=False)
+        app = App(logging=False)
+
+    ..logger
+        If the default logger is enabled, it specifies the logger the app should use.
+        It can be changed as the following::
+
+        app = App(logger=MyCustomLogger())
     """
 
-    def __init__(self, templates_dir="templates", static_dir="static", exception_handler=None, host="127.0.0.1", port=5000, default_middleware=True):
+    def __init__(self, templates_dir: str = "templates", static_dir: str = "static", exception_handler=None, host: str = "127.0.0.1", port=5000, logging=True, logger=Logger()):
         self.routes = {}
 
         # The host
@@ -88,43 +84,26 @@ class App:
 
         self.templates_dir = templates_dir
 
-        self.templates_env = Environment(
-            loader=FileSystemLoader(os.path.abspath(self.templates_dir)))
-
         if exception_handler is None:
             self.exception_handler = DefaultExceptionHandler(self)
         else:
             self.exception_handler = exception_handler()
 
-        self.whitenoise = WhiteNoise(self.wsgi_app, root=static_dir)
-
-        self.static_app = StaticFiles(directory=static_dir)
-
         self.middleware = Middleware(self)
 
-        if default_middleware:
-            self.add_middleware(DefaultMiddleware)
-        
-        self.static_test = StaticFile(static_dir)
+        if logging:
+            self.add_middleware(LoggingMiddleware)
+
+        self.static_app = StaticFile(static_dir)
 
         self.collections = []
 
-        # def serve_static(self, scope, recieve, send, path):
-        #     ...
+        self.add_route("/static/{filename}", self.static_app)
 
-        # self.add_route("/static", self.static_app)
-        
-        self.add_route("/static/{filename}", self.static_test)
+        self.logger = logger
 
-    async def wsgi_app(self, scope, recieve, send):
-        request = Request(scope, recieve=recieve)
-
-        response = self.handle_request(request)
-
-        await response(scope, recieve, send)
-
-    async def __call__(self, scope, recieve, send):
-        await self.middleware(scope, recieve, send)
+    async def __call__(self, scope, receive, send):
+        await self.middleware(scope, receive, send)
 
     def handle_request(self, request):
         handler, kwargs = self.find_handler(request_path=request.url.path)
@@ -139,16 +118,16 @@ class App:
 
                 response = handler(request, **kwargs)
             else:
-                return self.default_response()
+                return self.default_response(request)
 
         except Exception as e:
             error = traceback.format_exc()
-            response = self.exception_handler.handle_error(error)
+            response = self.exception_handler.handle_error(request, error)
 
         return response
 
-    def default_response(self):
-        return self.exception_handler.handle_404()
+    def default_response(self, request):
+        return self.exception_handler.handle_404(request)
 
     def find_handler(self, request_path):
         for path, handler in self.routes.items():
@@ -173,18 +152,6 @@ class App:
 
         self.routes[path] = handler
 
-    def template(self, template_name, context=None):
-        if context is None:
-            context = {}
-
-        return self.templates_env.get_template(template_name).render(**context).encode()
-
-    def custom_template(self, templates_path, template_name, context=None):
-        if context is None:
-            context = {}
-
-        return Environment(loader=FileSystemLoader(templates_path)).get_template(template_name).render(**context).encode()
-
     def add_middleware(self, middleware_cls):
         self.middleware.add(middleware_cls)
 
@@ -193,19 +160,6 @@ class App:
             loader=FileSystemLoader(os.path.abspath(templates_dir)))
         self.templates_dir = templates_dir
 
-    def set_cookie(self, key, value, resp, lifetime=None, secure=False):
-        if lifetime is not None:
-            resp.set_cookie(key, value, secure=secure)
-        else:
-            resp.set_cookie(
-                key, value, max_age=lifetime, secure=secure)
-
-    def get_cookies(self, req):
-        return req.cookies
-
-    def get_cookie(self, key, req):
-        return dict(req.cookies)[key]
-
     def register_collection(self, collection):
         assert collection not in self.collections, f"Collection {collection} already registered"
         collection.set_wsgi(self.wsgi_app)
@@ -218,7 +172,8 @@ class App:
         self.collections.append(collection)
 
     def run(self):
-        print(f"[INFO] Running on http://{self.host}:{self.port}")
-        print(f"[INFO] Press CTRL + C to stop")
+        self.logger.log(f"Running on http://{self.host}:{self.port}", "info")
+        self.logger.log(f"Press CTRL + C to stop", "info")
         uvicorn.run(self, host="127.0.0.1", port=5000,
                     log_level="critical")
+        self.logger.log("Exiting Application", "critical")
