@@ -5,7 +5,7 @@ with open("README.md", "r", encoding="utf-8") as fh:
 
 setuptools.setup(
     name="arcframework",  # Replace with your own username
-    version="1.9.0",
+    version="1.9.1",
     author="Rayyan Cyclegar",
     author_email="aboominister@gmail.com",
     description="A Python micro web framework for creating dynamic websites.",
@@ -20,10 +20,10 @@ setuptools.setup(
     ],
     python_requires='>=3.8',
     install_requires=[
-        'webob', "uvicorn", "whitenoise", "parse", "jinja2"
+        "uvicorn", "parse", "jinja2", "starlette"
     ],
     include_package_data=True,
     package_data={
         "arc": ["selfpages/*.html", "static/*.css"],
     }
-)
\ No newline at end of file
+)
